@@ -265,3 +265,14 @@ class FlaviusPickupLocationFileUpload(FlaviusBase):
     def create(self, query=None):
         with requests.post(self.create_url, files=query, data=query) as response:
             return response.json()
+
+
+class FlaviusPrintPackingLabel(FlaviusBase):
+    """
+    ラベルプリンタ印刷用API
+    """
+    def __init__(self):
+        super(FlaviusPrintPackingLabel, self).__init__(search_url='',
+                                                       create_url=conf.FLAVIUS_API_PRINT_PACKING_LABEL,
+                                                       update_url='',
+                                                       delete_url='')
