@@ -135,6 +135,10 @@ class Settings:
     def FLAVIUS_API_HEADER_EXT_PICKUP_DELETE(self):
         return getattr(settings, "FLAVIUS_API_HEADER_EXT_PICKUP_DELETE", 'api/header_ext_pickup_delete.php')
 
+    @property
+    def FLAVIUS_API_PRINT_PACKING_LABEL(self):
+        return getattr(settings, "FLAVIUS_API_PRINT_PACKING_LABEL", 'api/print_packing_label.php')
+
     @property
     def EXCLUDE_TAX(self):
         return getattr(settings, "EXCLUDE_TAX", '91100')
